Watson-Common
=============

Useful common utility functions and classes for working with lists,
dictionaries, importlib and xml.

For full documentation please see `Read The
Docs <http://watson-common.readthedocs.org/>`__.

Build Status
^^^^^^^^^^^^

|Build Status| |Coverage Status| |Version|

Installation
------------

``pip install watson-common``

Requirements
------------

.. |Build Status| image:: https://img.shields.io/travis/watsonpy/watson-common.svg?maxAge=2592000
   :target: https://travis-ci.org/watsonpy/watson-common
.. |Coverage Status| image:: https://img.shields.io/coveralls/watsonpy/watson-common.svg?maxAge=2592000
   :target: https://coveralls.io/r/watsonpy/watson-common
.. |Version| image:: https://img.shields.io/pypi/v/watson-common.svg?maxAge=2592000
   :target: https://pypi.python.org/pypi/watson-common/
